/*
 * Main Layout on Lock Screen extension for GNOME Shell 45+
 * Copyright 2023 Paulo Fino (@somepaulo), 2022 Sagi (@sagidayan)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * If this extension breaks your desktop you get to keep all of the pieces...
 */

import {Extension} from 'resource:///org/gnome/shell/extensions/extension.js';
import * as Main from "resource:///org/gnome/shell/ui/main.js";
import * as KeyboardStatus from 'resource:///org/gnome/shell/ui/status/keyboard.js';
const inputSourceManager = KeyboardStatus.getInputSourceManager();

export default class PrimaryInputOnLockScreen extends Extension {
    constructor(metadata) {
        super(metadata);
        this._lockScreenHandlerId = null;
    }

    enable() {
        if (this._lockScreenHandlerId) return;
        this._lockScreenHandlerId = Main.screenShield.connect('lock-screen-shown', this._check_state);
    }
    
    disable() {
        /*
        // This extensions uses `unlock-dialog`
        // because it only needs to operate on the unlock screen
        // in order to check and change the current keyboard layout.
        */
        if (this._lockScreenHandlerId) {
            Main.screenShield.disconnect(this._lockScreenHandlerId);
            this._lockScreenHandlerId = null;
        }
        inputSourceManager = null;
    }
    
    _check_state() {
        try {
            const primaryInput = inputSourceManager.inputSources["0"];
            const currentInput = inputSourceManager.currentSource;
            if (currentInput != primaryInput) {
                primaryInput.activate();
            }
        } catch (err) {
            console.error(`[PRIMARY_LOCK]: ERROR: ${err}`)
        }
    }
}
